gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r8600 - in gnunet/src: include testing


From: gnunet
Subject: [GNUnet-SVN] r8600 - in gnunet/src: include testing
Date: Wed, 17 Jun 2009 20:24:56 -0600

Author: grothoff
Date: 2009-06-17 20:24:56 -0600 (Wed, 17 Jun 2009)
New Revision: 8600

Modified:
   gnunet/src/include/gnunet_testing_lib.h
   gnunet/src/testing/testing.c
   gnunet/src/testing/testing_testbed.c
Log:
fix

Modified: gnunet/src/include/gnunet_testing_lib.h
===================================================================
--- gnunet/src/include/gnunet_testing_lib.h     2009-06-18 02:21:46 UTC (rev 
8599)
+++ gnunet/src/include/gnunet_testing_lib.h     2009-06-18 02:24:56 UTC (rev 
8600)
@@ -144,6 +144,41 @@
  * @param cbe function to call at the end
  * @param cbe_cls closure for cbe
  * @param hostname where to run the peers; can be NULL (to run
+ *        everything on localhost).
+ * @param va Additional hosts can be specified using a NULL-terminated list of
+ *        varargs, hosts will then be used round-robin from that
+ *        list; va only contains anything if hostname != NULL.
+ */
+void
+GNUNET_TESTING_daemons_start_Va (struct GNUNET_SCHEDULER_Handle *sched,
+                                struct GNUNET_CONFIGURATION_Handle *cfg,
+                                unsigned int total,
+                                const char *service_home_prefix,
+                                const char *transports,
+                                const char *applications,
+                                GNUNET_TESTING_NotifyDaemonRunning cb,
+                                void *cb_cls,
+                                GNUNET_TESTING_NotifyCompletion cbe,
+                                void *cbe_cls,
+                                const char *hostname,
+                                va_list va);
+
+/**
+ * Start count gnunetd processes with the same set of
+ * transports and applications.  The port numbers will
+ * be computed by adding delta each time (zero
+ * times for the first peer).
+ *
+ * @param total number of daemons to start
+ * @param service_home_prefix path to use as the prefix for the home of the 
services
+ * @param transports which transports should all peers use
+ * @param applications which applications should be used?
+ * @param timeout how long is this allowed to take?
+ * @param cb function to call on each daemon that was started
+ * @param cb_cls closure for cb
+ * @param cbe function to call at the end
+ * @param cbe_cls closure for cbe
+ * @param hostname where to run the peers; can be NULL (to run
  *        everything on localhost). Additional
  *        hosts can be specified using a NULL-terminated list of
  *        varargs, hosts will then be used round-robin from that
@@ -254,40 +289,6 @@
                              ...);
 
 
-/**
- * Start count GNUnet daemons with a particular
- * topology.
- *
- * @param size number of peers the testbed should have
- * @param topology desired topology (enforced via F2F)
- * @param service_home_prefix path to use as the prefix for the home of the 
services
- * @param transports which transports should all peers use
- * @param applications which applications should be used?
- * @param timeout how long is this allowed to take?
- * @param cb function to call on each daemon that was started
- * @param cb_cls closure for cb
- * @param cte function to call at the end
- * @param cte_cls closure for cbe
- * @param hostname where to run the peers; can be NULL (to run
- *        everything on localhost).
- * @param va Additional hosts can be specified using a NULL-terminated list of
- *        varargs, hosts will then be used round-robin from that
- *        list; va only contains anything if hostname != NULL.
- */
-void
-GNUNET_TESTING_testbed_start_va (struct GNUNET_SCHEDULER_Handle *sched,
-                                struct GNUNET_CONFIGURATION_Handle *cfg,
-                                unsigned int size,
-                                enum GNUNET_TESTING_Topology topology,
-                                const char *service_home_prefix,
-                                const char *transports,
-                                const char *applications,
-                                GNUNET_TESTING_NotifyDaemonRunning cb,
-                                void *cb_cls,
-                                GNUNET_TESTING_NotifyTestbedRunning cte,
-                                void *cte_cls,
-                                const char *hostname,
-                                va_list ap);
 
 
 /**

Modified: gnunet/src/testing/testing.c
===================================================================
--- gnunet/src/testing/testing.c        2009-06-18 02:21:46 UTC (rev 8599)
+++ gnunet/src/testing/testing.c        2009-06-18 02:24:56 UTC (rev 8600)
@@ -99,19 +99,20 @@
 
 
 /**
- * Start count GNUnet daemons with a particular
- * topology.
+ * Start count gnunetd processes with the same set of
+ * transports and applications.  The port numbers will
+ * be computed by adding delta each time (zero
+ * times for the first peer).
  *
- * @param size number of peers the testbed should have
- * @param topology desired topology (enforced via F2F)
+ * @param total number of daemons to start
  * @param service_home_prefix path to use as the prefix for the home of the 
services
  * @param transports which transports should all peers use
  * @param applications which applications should be used?
  * @param timeout how long is this allowed to take?
  * @param cb function to call on each daemon that was started
  * @param cb_cls closure for cb
  * @param cte function to call at the end
  * @param cte_cls closure for cbe
  * @param hostname where to run the peers; can be NULL (to run
  *        everything on localhost).
  * @param va Additional hosts can be specified using a NULL-terminated list of
@@ -119,19 +120,18 @@
  *        list; va only contains anything if hostname != NULL.
  */
 void
-GNUNET_TESTING_testbed_start_va (struct GNUNET_SCHEDULER_Handle *sched,
+GNUNET_TESTING_daemons_start_va (struct GNUNET_SCHEDULER_Handle *sched,
                                 struct GNUNET_CONFIGURATION_Handle *cfg,
-                                unsigned int size,
-                                enum GNUNET_TESTING_Topology topology,
+                                unsigned int total,
                                 const char *service_home_prefix,
                                 const char *transports,
                                 const char *applications,
                                 GNUNET_TESTING_NotifyDaemonRunning cb,
                                 void *cb_cls,
-                                GNUNET_TESTING_NotifyTestbedRunning cte,
-                                void *cte_cls,
+                                GNUNET_TESTING_NotifyCompletion cbe,
+                                void *cbe_cls,
                                 const char *hostname,
-                                va_list ap)
+                                va_list va)
 {
 }
 
@@ -182,12 +182,4 @@
   va_end (va);
 }
 
-
-#if 0                           /* keep Emacsens' auto-indent happy */
-{
-#endif
-#ifdef __cplusplus
-}
-#endif
-
-#endif
+/* end of testing.c */

Modified: gnunet/src/testing/testing_testbed.c
===================================================================
--- gnunet/src/testing/testing_testbed.c        2009-06-18 02:21:46 UTC (rev 
8599)
+++ gnunet/src/testing/testing_testbed.c        2009-06-18 02:24:56 UTC (rev 
8600)
@@ -122,13 +122,3 @@
                              void *cb_cls)
 {
 }
-
-
-#if 0                           /* keep Emacsens' auto-indent happy */
-{
-#endif
-#ifdef __cplusplus
-}
-#endif
-
-#endif
@@ -99,19 +99,20 @@
  * @param cb function to call on each daemon that was started
  * @param cb_cls closure for cb
- * @param cte function to call at the end
- * @param cte_cls closure for cbe
+ * @param cbe function to call at the end
+ * @param cbe_cls closure for cbe
  * @param hostname where to run the peers; can be NULL (to run
  *        everything on localhost).





reply via email to

[Prev in Thread] Current Thread [Next in Thread]